# Define libsuffix, minimum libyui-devel version
# and so-version of libyui.
%global libsuffix yui
%global libname lib%{libsuffix}
%global devel_min_ver 3.1.2
%global major_so_ver 7

# Setup _pkgdocdir if not defined already.
%{!?_pkgdocdir:%global _pkgdocdir %{_docdir}/%{name}-%{version}}

# CMake-builds go out-of-tree.
%global _cmake_build_subdir build-%{?_arch}%{?dist}

Name:			%{libname}-qt
Version:		2.46.18
Release:		1%{?dist}
Summary:		Qt User Interface for %{libname}

License:		LGPLv2 or LGPLv3
URL:			https://github.com/%{libname}/%{name}
Source0:		%{url}/archive/%{name}/master/%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildRequires:		boost-devel
BuildRequires:		cmake				>= 2.8
BuildRequires:		fontconfig-devel
BuildRequires:		%{libname}-devel		>= %{devel_min_ver}
BuildRequires:		pkgconfig(Qt5Core)
BuildRequires:		pkgconfig(Qt5Gui)
BuildRequires:		pkgconfig(Qt5Svg)
BuildRequires:		pkgconfig(Qt5Widgets)
BuildRequires:		pkgconfig(Qt5X11Extras)

Provides:		%{libsuffix}-ui%{?_isa}		== %{major_so_ver}

%description
This package contains the qt user interface component
for %{libname}.


%package devel
Summary:		Files needed for developing with %{name}

Requires:		fontconfig-devel%{?_isa}
Requires:		%{libname}-devel%{?_isa}	>= %{devel_min_ver}
Requires:		%{name}%{?_isa}			== %{version}-%{release}
Requires:		qt5-qtbase-devel%{?_isa}
Requires:		qt5-qtsvg-devel%{?_isa}
Requires:		qt5-qtx11extras-devel%{?_isa}

%if 0%{?fedora} && 0%{?fedora} <= 22
Obsoletes:		%{name}-devel-common		<= %{version}-%{release}
%endif #0%{?fedora} && 0%{?fedora} <= 22

%description devel
%{libname} can be used independently of YaST for generic (C++)
applications and has very few dependencies.

You do NOT need this package for developing with %{libname}.
Using %{libname}-devel is sufficient for such purpose.  This
package is only needed when you want to develop an extension
for %{name} which is not covered within the UI-plugin.


%package doc
Summary:		Documentation files for %{name}
BuildArch:		noarch

BuildRequires:		doxygen
BuildRequires:		graphviz
BuildRequires:		hardlink

%description doc
This package includes the developer's documentation as HTML
for %{name}.


%prep
%setup -qn %{name}-%{name}-master-%{version}
./bootstrap.sh


%build
%{__mkdir} -p %{_cmake_build_subdir}
pushd %{_cmake_build_subdir}
%cmake							\
       	-DENABLE_WERROR=OFF                             \
	-DYPREFIX=%{_prefix}				\
	-DLIB_DIR=%{_libdir}				\
	-DCMAKE_BUILD_TYPE=RELEASE			\
	-DRESPECT_FLAGS=ON				\
	..

%{__make} %{?_smp_mflags}
%{__make} %{?_smp_mflags} docs
popd


%install
pushd %{_cmake_build_subdir}
%{__mkdir} -p	%{buildroot}%{_libdir}/%{libsuffix}	\
		%{buildroot}%{_datadir}/%{name}/theme

%make_install

# Delete obsolete files.
%{__rm} -rf	%{buildroot}%{_defaultdocdir}		\
		doc/html/*.m*

# Hard-link documentation.
%{_sbindir}/hardlink -cv doc/html

# Install documentation.
%{__mkdir} -p	%{buildroot}%{?_pkgdocdir}
%{__cp} -a	../ChangeLog ../COPYING* doc/html/	\
		%{buildroot}%{?_pkgdocdir}
popd


%files
%doc %dir %{?_pkgdocdir}
%doc %{?_pkgdocdir}/COPYING*
%{_libdir}/%{libsuffix}/%{name}.so.%{major_so_ver}*

%files devel
%doc %{?_pkgdocdir}/ChangeLog
%{_includedir}/%{libsuffix}/*
%{_libdir}/%{libsuffix}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake

%files doc
%doc %{?_pkgdocdir}


%changelog
* Thu Aug 27 2015 Björn Esser <bjoern.esser@gmail.com> - 2.46.18-1
- new upstream release

* Mon Aug 10 2015 Björn Esser <bjoern.esser@gmail.com> - 2.46.13-8
- disable '-Werror'

* Wed Jul 29 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.46.13-7
- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159

* Wed Jul 22 2015 David Tardon <dtardon@redhat.com> - 2.46.13-6
- rebuild for Boost 1.58

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.46.13-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon May 04 2015 Kalev Lember <kalevlember@gmail.com> - 2.46.13-4
- Rebuilt for GCC 5 C++11 ABI change

* Mon Feb 02 2015 Björn Esser <bjoern.esser@gmail.com> - 2.46.13-3
- rebuilt for libyui-3.1.5, again

* Mon Feb 02 2015 Björn Esser <bjoern.esser@gmail.com> - 2.46.13-2
- Rebuild for boost 1.57.0

* Tue Jan 20 2015 Björn Esser <bjoern.esser@gmail.com> - 2.46.13-1
- new upstream release (#1183542)
- rebuilt for libyui-3.1.5
- keep doc-files in unfied %%{_pkgdocdir}
- small improvements to spec-file

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.46.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.46.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat May 24 2014 Björn Esser <bjoern.esser@gmail.com> - 2.46.1-2
- no need to provide `%%{name}-devel-common`

* Fri May 23 2014 Björn Esser <bjoern.esser@gmail.com> - 2.46.1-1
- new upstream release (#1051417)

* Fri May 23 2014 Björn Esser <bjoern.esser@gmail.com> - 2.43.5-3
- Rebuild for boost 1.55.0

* Tue Mar 18 2014 Björn Esser <bjoern.esser@gmail.com> - 2.43.5-2
- rebuilt for libyui-3.0.13
- remove build of pdf-autodocs
- remove the devel-common subpkg
- minor improvents on spec

* Fri Aug 30 2013 Björn Esser <bjoern.esser@gmail.com> - 2.43.5-1
- new upstream version
- restructured spec to match with libyui

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.43.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon May 20 2013 Björn Esser <bjoern.esser@gmail.com> - 2.43.3-2
- changed Provides: `yui_ui =` from `version` to `major_so_ver`
- install lib*.so.`major_so_ver`* in main-pkg not lib*.so.*
- add `-DRESPECT_FLAGS=ON`, will be honored by libyui >= 3.0.5
- removed macros from changelog

* Wed May 15 2013 Björn Esser <bjoern.esser@gmail.com> - 2.43.3-1
- new upstream version
- adjusted libyui-devel min-version
- added needed bootstrap to prep

* Mon May 13 2013 Björn Esser <bjoern.esser@gmail.com> - 2.43.2-1
- Initial RPM release.
